# WARNING: Synchronized with Fedora!

# Mageia does not currently have a Koji instance
# available on its infrastructure yet, so for now,
# the patch for using it with the koji CLI client is
# disabled. (ngompa)
%bcond_with use_mga_cli_cfg

Name: koji
Version: 1.32.0
Release: %mkrel 2
License: LGPLv2
Summary: Build system tools
Group: System/Packaging
URL: https://koji.build/

Source: https://releases.pagure.org/%{name}/%{name}-%{version}.tar.bz2

# Patches from upstream

# Patches proposed upstream
## Unify database schema migration script
## From: https://pagure.io/koji/pull-request/3697
Patch0101: https://pagure.io/koji/pull-request/3697.patch#/koji-PR3697.patch

# Mageia-specific patches
# Set up defaults for the Koji CLI client
Patch1001: mageia-koji-cli-config.patch

BuildArch: noarch

Requires: python3-%{name} = %{version}-%{release}

BuildRequires: python3-sphinx
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig
BuildRequires: sed

%description
Koji is a system for building and tracking RPMS.  The base package
contains the command-line interface.

%package -n python3-%{name}
Summary: Build system tools python library
Group: Development/Python
%{?python_provide:%python_provide python3-%{name}}
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: make
BuildRequires: python3-pip
BuildRequires: python3-wheel
Requires: python3-rpm
Requires: python3-requests
Requires: python3-requests-gssapi
Requires: python3-dateutil
Requires: python3-six
Requires: python3-libcomps
# Python 2 subpackage is dropped
Obsoletes: python2-%{name} < 1.17.0

%description -n python3-%{name}
Koji is a system for building and tracking RPMS.  This package
contains shared libraries.

%package -n python3-%{name}-cli-plugins
Summary: Koji client plugins
Group: System/Packaging
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
# Python 2 subpackage is dropped
Obsoletes: python2-%{name}-cli-plugins < 1.17.0

%description -n python3-%{name}-cli-plugins
Plugins to the koji command-line interface

%package hub
Summary: Koji XMLRPC interface
Group: System/Servers
License: LGPLv2 and GPLv2
# rpmdiff lib (from rpmlint) is GPLv2 (only)
Requires: apache
Requires: apache-python3-mod_wsgi
Requires: apache-mod_auth_gssapi
Requires: python3-psycopg2
Requires: python3-%{name} = %{version}-%{release}
Suggests: %{name}-hub-plugins

%description hub
koji-hub is the XMLRPC interface to the koji database

%package hub-plugins
Summary: Koji hub plugins
Group: System/Servers
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
Requires: %{name}-hub = %{version}-%{release}
# (ngompa): Cannot get qpid-proton to build
#Requires: python3-qpid-proton
Requires: cpio

%description hub-plugins
Plugins to the koji XMLRPC interface

%package builder
Summary: Koji RPM builder daemon
Group: System/Packaging
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
Requires: mock >= 0.9.14
Requires(pre): shadow-utils
Requires: squashfs-tools
Requires: python3-dnf
Requires: python3-librepo
Requires: python3-multilib
Requires: python3-cheetah
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: cvs
Requires: subversion
Requires: git-core
Requires: createrepo_c

%description builder
koji-builder is the daemon that runs on build machines and executes
tasks that come through the Koji system.

%package builder-plugins
Summary: Koji builder plugins
Group: System/Packaging
License: LGPLv2
Requires: %{name} = %{version}-%{release}
Requires: %{name}-builder = %{version}-%{release}
Enhances: %{name}-builder

%description builder-plugins
Plugins for the koji build daemon

%package vm
Summary: Koji virtual machine management daemon
Group: System/Servers
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: python3-libvirt
Requires: libxml2-python3
Requires: virt-clone
Requires: qemu-img

%description vm
koji-vm contains a supplemental build daemon that executes certain tasks in a
virtual machine. This package is not required for most installations.

%package utils
Summary: Koji Utilities
Group: System/Packaging
License: LGPLv2
Requires: python3-psycopg2
Requires: python3-%{name} = %{version}-%{release}

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description utils
Utilities for the Koji system

%package web
Summary: Koji Web UI
Group: System/Servers
License: LGPLv2
Requires: apache
Requires: apache-python3-mod_wsgi
Requires: apache-mod_auth_gssapi
Requires: python3-psycopg2
Requires: python3-cheetah
Requires: python3-%{name} = %{version}-%{release}

%description web
koji-web is a web UI to the Koji system.

%prep
%autosetup -p1

%if ! %{with use_mga_cli_cfg}
%patch1001 -p1 -R
%endif

# we'll be packaging these separately and don't want them registered
# to the wheel we will produce.
sed -e '/util\/koji/g' -e '/koji_cli_plugins/g' -i setup.py

%build
%py3_build_wheel

%install
%py3_install_wheel %{name}-%{version}-py3-none-any.whl
mkdir -p %{buildroot}/etc/koji.conf.d
cp cli/koji.conf %{buildroot}/etc/koji.conf
for D in kojihub builder plugins util www vm ; do
    pushd $D
    %make_install PYTHON=%{__python3}
    popd
done

# alter python interpreter in koji CLI
scripts='%{_bindir}/koji %{_sbindir}/kojid %{_sbindir}/kojira %{_sbindir}/koji-shadow
         %{_sbindir}/koji-gc %{_sbindir}/kojivmd %{_sbindir}/koji-sweep-db
         %{_sbindir}/koji-sidetag-cleanup'
for fn in $scripts ; do
    sed -i 's|#!/usr/bin/python2|#!/usr/bin/python3|' $RPM_BUILD_ROOT$fn
done

# handle extra byte compilation
extra_dirs='
    %{_prefix}/lib/koji-builder-plugins
    %{_prefix}/koji-hub-plugins
    %{_datadir}/koji-hub
    %{_datadir}/koji-web/lib/kojiweb
    %{_datadir}/koji-web/scripts'
for fn in $extra_dirs ; do
    %py_byte_compile %{__python3} %{buildroot}$fn
done

%files
%{_bindir}/*
%config(noreplace) %{_sysconfdir}/koji.conf
%dir %{_sysconfdir}/koji.conf.d
%doc docs Authors
%license COPYING LGPL

%files -n python3-%{name}
%{python3_sitelib}/%{name}
%{python3_sitelib}/koji_cli
%{python3_sitelib}/%{name}-%{version}.dist-info/

%files -n python3-%{name}-cli-plugins
%{python3_sitelib}/koji_cli_plugins
# we don't have config files for default plugins yet
#%%dir %{_sysconfdir}/koji/plugins
#%%config(noreplace) %{_sysconfdir}/koji/plugins/*.conf


%files hub
%{_datadir}/koji-hub
%{python3_sitelib}/kojihub
%config(noreplace) %{_sysconfdir}/httpd/conf.d/kojihub.conf
%dir %{_sysconfdir}/koji-hub
%config(noreplace) %{_sysconfdir}/koji-hub/hub.conf
%dir %{_sysconfdir}/koji-hub/hub.conf.d
%{_sbindir}/koji-sweep-db
%{_unitdir}/koji-sweep-db.service
%{_unitdir}/koji-sweep-db.timer

%files hub-plugins
%dir %{_prefix}/lib/koji-hub-plugins
%{_prefix}/lib/koji-hub-plugins/*.py*
%{_prefix}/lib/koji-hub-plugins/__pycache__/
%dir %{_sysconfdir}/koji-hub/plugins
%{_sysconfdir}/koji-hub/plugins/*.conf
# (ngompa): Cannot get qpid-proton to build
%exclude %{_prefix}/lib/koji-hub-plugins/protonmsg*
%exclude %{_prefix}/lib/koji-hub-plugins/__pycache__/protonmsg*
%exclude %{_sysconfdir}/koji-hub/plugins/protonmsg*

%files utils
%{_sbindir}/kojira
%{_unitdir}/kojira.service
%{_unitdir}/koji-gc.service
%{_unitdir}/koji-gc.timer
%dir %{_sysconfdir}/kojira
%config(noreplace) %{_sysconfdir}/kojira/kojira.conf
%{_sbindir}/koji-gc
%dir %{_sysconfdir}/koji-gc
%config(noreplace) %{_sysconfdir}/koji-gc/koji-gc.conf
%config(noreplace) %{_sysconfdir}/koji-gc/email.tpl
%{_sbindir}/koji-shadow
%dir %{_sysconfdir}/koji-shadow
%config(noreplace) %{_sysconfdir}/koji-shadow/koji-shadow.conf
%{_sbindir}/koji-sidetag-cleanup

%files web
%{_datadir}/koji-web
%dir %{_sysconfdir}/kojiweb
%config(noreplace) %{_sysconfdir}/kojiweb/web.conf
%config(noreplace) %{_sysconfdir}/httpd/conf.d/kojiweb.conf
%dir %{_sysconfdir}/kojiweb/web.conf.d

%files builder
%{_sbindir}/kojid
%defattr(-,root,root)
%{_unitdir}/kojid.service
%dir %{_sysconfdir}/kojid
%config(noreplace) %{_sysconfdir}/kojid/kojid.conf
%attr(-,kojibuilder,kojibuilder) %{_sysconfdir}/mock/koji

%files builder-plugins
%dir %{_sysconfdir}/kojid/plugins
%config(noreplace) %{_sysconfdir}/kojid/plugins/*.conf
%dir %{_prefix}/lib/koji-builder-plugins
%{_prefix}/lib/koji-builder-plugins/*.py*
%{_prefix}/lib/koji-builder-plugins/__pycache__


%pre builder
/usr/sbin/useradd -r -s /bin/bash -G mock -d /builddir -M kojibuilder 2>/dev/null ||:

%post builder
%systemd_post kojid.service

%preun builder
%systemd_preun kojid.service

%files vm
%{_sbindir}/kojivmd
%dir %{_datadir}/kojivmd
%{_datadir}/kojivmd/kojikamid
%{_unitdir}/kojivmd.service
%dir %{_sysconfdir}/kojivmd
%config(noreplace) %{_sysconfdir}/kojivmd/kojivmd.conf

%post vm
%systemd_post kojivmd.service

%preun vm
%systemd_preun kojivmd.service


%post utils
%systemd_post kojira.service

%preun utils
%systemd_preun kojira.service





%changelog
* Fri Mar 15 2024 papoteur <papoteur> 1.32.0-2.mga10
+ Revision: 2049991
- rebuild for python 3.12

* Sat Feb 18 2023 ngompa <ngompa> 1.32.0-1.mga9
+ Revision: 1943898
- Rebase to version 1.32.0
+ neoclust <neoclust>
- New version 1.30.0

* Tue Mar 29 2022 umeabot <umeabot> 1.23.0-4.mga9
+ Revision: 1832938
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 1.23.0-3.mga9
+ Revision: 1787296
- rebuild for python-3.10

* Sat Jun 26 2021 wally <wally> 1.23.0-2.mga9
+ Revision: 1732399
- Rebuild for python 3.9

* Mon Dec 28 2020 ngompa <ngompa> 1.23.0-1.mga8
+ Revision: 1664596
- Rebase to version 1.23.0

* Sun Feb 16 2020 umeabot <umeabot> 1.17.0-3.mga8
+ Revision: 1535857
- Mageia 8 Mass Rebuild

* Sun Oct 13 2019 tv <tv> 1.17.0-2.mga8
+ Revision: 1452777
- rebuild with python 3.8

* Sun Mar 10 2019 ngompa <ngompa> 1.17.0-1.mga7
+ Revision: 1373439
- Update to 1.17.0
- Drop upstream patches
- Switch to Python 3
- Replace our patch with upstream proposed one to use createrepo_c by default

* Wed Jan 30 2019 ngompa <ngompa> 1.16.1-4.mga7
+ Revision: 1361988
- Backport patch to fix Python 3 connection bug

* Wed Jan 09 2019 shlomif <shlomif> 1.16.1-3.mga7
+ Revision: 1353319
- Rebuild for python3 3.7

* Thu Oct 18 2018 ngompa <ngompa> 1.16.1-2.mga7
+ Revision: 1321979
- Fix bad sed that caused python32 dep

* Tue Oct 16 2018 ngompa <ngompa> 1.16.1-1.mga7
+ Revision: 1321163
- Update to 1.16.1

* Thu Sep 20 2018 umeabot <umeabot> 1.16.0-2.mga7
+ Revision: 1279187
- Mageia 7 Mass Rebuild

* Tue Jul 03 2018 ngompa <ngompa> 1.16.0-1.mga7
+ Revision: 1241461
- Update to 1.16.0

* Sun Apr 22 2018 ngompa <ngompa> 1.15.1-2.mga7
+ Revision: 1221040
- Add proposed patch to support setting macros for tags/targets

* Sat Apr 21 2018 ngompa <ngompa> 1.15.1-1.mga7
+ Revision: 1220784
- Upgrade to koji 1.15.1 to fix CVE-2018-1002150

* Tue Dec 19 2017 ngompa <ngompa> 1.15.0-1.mga7
+ Revision: 1183490
- Upgrade to v1.15.0
- Drop backported patches

* Sun Dec 10 2017 ngompa <ngompa> 1.14.0-1.mga7
+ Revision: 1181838
- Rebase to version 1.14.0
- Split out Python API into subpackages and switch CLI to Python 3
- Backport py3 keytab patch (PR#708)
- Backport patches for exit code (issue#696)
- Backport py3 runroot encoding patch (PR#735)
- Backport support for rendering license tag information (PR#686)
- Add patches to properly support functioning with Mock 1.4+ (PR#602)

* Sun May 14 2017 ngompa <ngompa> 1.12.0-2.mga6
+ Revision: 1101048
- Backport patch for kojid for non-SSL auth

* Wed Apr 19 2017 ngompa <ngompa> 1.12.0-1.mga6
+ Revision: 1096749
- Upgrade to v1.12.0
- Drop merged patches
- Move Mageia configuration patches to the end for easier rebasing

* Sat Dec 17 2016 ngompa <ngompa> 1.11.0-3.mga6
+ Revision: 1075744
- Fix broken Requires (shadowutils->shadow-utils)

* Fri Dec 16 2016 ngompa <ngompa> 1.11.0-2.mga6
+ Revision: 1075735
- Downgrading python-krbV dependency to Recommends, as it's a fallback mechanism now

* Mon Dec 12 2016 ngompa <ngompa> 1.11.0-1.mga6
+ Revision: 1074306
- Update to koji 1.11.0
- Add patch to enable picking up username from krb ticket
- Add patch to convert from PyGreSQL to psycopg2

* Sun May 08 2016 ngompa <ngompa> 1.10.1-9.mga6
+ Revision: 1011004
- imported package koji


* Sun May 08 2016 Neal Gompa <ngompa13@gmail.com> - 1.10.1-9
- Port to Mageia

* Fri Apr 08 2016 Dennis Gilmore <dennis@ausil.us> - 1.10.1-8
- do not remove the - for project on livemedia
- fix the sending of messages on image completion

* Thu Apr 07 2016 Dennis Gilmore <dennis@ausil.us> - 1.10.1-7
- --product had to be --project
- add missing Requires for koji-builder on python2-multilib

* Wed Apr 06 2016 Dennis Gilmore <dennis@ausil.us> - 1.10.1-6
- add --product to livemedia-creator calls rhbz#1315110

* Wed Apr 06 2016 Dennis Gilmore <dennis@ausil.us> - 1.10.1-5
- enable dns in runroots
- add koji signed repo support
- Run plugin callbacks when image builds finish

* Thu Mar 03 2016 Dennis Gilmore <dennis@ausil.us> - 1.10.1-4
- add a patch to install the runroot builder plugin in the correct place

* Tue Mar 01 2016 Dennis Gilmore <dennis@ausil.us> - 1.10.1-3
- update to git e8201aac8294e6125a73504886b0800041b58868
- https://pagure.io/fork/ausil/koji/branch/fedora-infra

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.10.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 17 2015 Dennis Gilmore <dennis@ausil.us> - 1.10.1-1
- update to 1.10.1
- Requires yum in the cli rhbz#1230888

* Thu Sep 24 2015 Kalev Lember <klember@redhat.com> - 1.10.0-2
- Backport two patches to fix ClientSession SSL errors

* Thu Jul 16 2015 Dennis Gilmore <dennis@ausil.us> - 1.10.0=1
- update to 1.10.0 release

* Mon Jul 06 2015 Dennis Gilmore <dennis@ausil.us> - 1.9.0-13.20150607gitf426fdb
- update the git snapshot to latest head
- enable systemd units for f23 up

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.0-12.20150423git52a0188
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Apr 23 2015 Dennis Gilmore <dennis@ausil.us> - 1.9.0-11.20150423git52a0188
- update to latest git

* Tue Jan 27 2015 Dennis Gilmore <dennis@ausil.us> - 1.9.0-10.gitcd45e886
- update to git tarball

* Thu Dec 11 2014 Dennis Gilmore <dennis@ausil.us> - 1.9.0-9
- add upstream patch switching to TLS1 from sslv3

* Tue Sep 30 2014 Dennis Gilmore <dennis@ausil.us> - 1.9.0-8
- don't exclude koji-vm from ppc and ppc64

* Fri Sep 26 2014 Till Maas <opensource@till.name> - 1.9.0-7
- Use https for kojipkgs
- Update URL

* Mon Aug 04 2014 Dennis Gilmore <dennis@ausil.us> - 1.9.0-6
- add patch to fix kickstart parsing

* Mon Aug 04 2014 Dennis Gilmore <dennis@ausil.us> - 1.9.0-5
- add upstream patches for better docker support

* Tue Jul 29 2014 Dennis Gilmore <dennis@ausil.us> - 1.9.0-4
- add upstream patch to compress docker images

* Thu Jun 12 2014 Dennis Gilmore <dennis@ausil.us> - 1.9.0-3
- add patch to move builder workdir to /var/tmp
- add support for making raw.xz images

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Mar 24 2014 Dennis Gilmore <dennis@ausil.us> - 1.9.0-1
- update to upstream 1.9.0

* Wed Jul 31 2013 Dennis Gilmore <dennis@ausil.us> - 1.8.0-2
- update from git snapshot

* Mon Apr 01 2013 Dennis Gilmore <dennis@ausil.us> - 1.8.0-1
- update to upstream 1.8.0

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Jan 20 2013 Dennis Gilmore <dennis@ausil.us> - 1.7.1-2
- revert "avoid baseurl option in createrepo" patch
- fix integer overflow issue in checkUpload handler

* Wed Nov 21 2012 Dennis Gilmore <dennis@ausil.us> - 1.7.1-1
- update to upstream 1.7.1 release

* Sat Sep 01 2012 Dennis Gilmore <dennis@ausil.us> - 1.7.0-7
- add patch to mount all of /dev on appliances and lives

* Fri Aug 31 2012 Dennis Gilmore <dennis@ausil.us> - 1.7.0-4
- add patch to only make /dev/urandom if it doesnt exist
- add upstream patch for taginfo fixes with older servers

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 05 2012 Dennis Gilmore <dennis@ausil.us> - 1.7.0-2
- use topurl not pkgurl in the fedora config

* Fri Jun 01 2012 Dennis Gilmore <dennis@ausil.us> - 1.7.0-1
- update to 1.7.0 many bugfixes and improvements
- now uses mod_wsgi 

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 17 2010 Dennis Gilmore <dennis@ausil.us> - 1.6.0-1
- update to 1.6.0

* Wed Dec 01 2010 Dennis Gilmore <dennis@ausil.us> - 1.5.0-1
- update to 1.5.0

* Tue Aug  3 2010 David Malcolm <dmalcolm@redhat.com> - 1.4.0-4
- fix python 2.7 incompatibilities (rhbz 619276)

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sat Jul 10 2010 Dennis Gilmore <dennis@ausil.us> - 1.4.0-2
- add missing Requires: python-cheetah from koji-builder

* Fri Jul 09 2010 Dennis Gilmore <dennis@ausil.us> - 1.4.0-1
- update to 1.4.0
- Merge mead branch: support for building jars with Maven *
- support for building appliance images *
- soft dependencies for LiveCD/Appliance features
- smarter prioritization of repo regenerations
- package list policy to determine if package list changes are allowed
- channel policy to determine which channel a task is placed in
- edit host data via webui
- description and comment fields for hosts *
- cleaner log entries for kojihub
- track user data in versioned tables *
- allow setting retry parameters for the cli
- track start time for tasks *
- allow packages built from the same srpm to span multiple external repos
- make the command used to fetch sources configuable per repo
- kojira: remove unexpected directories
- let kojid to decide if it can handle a noarch task
- avoid extraneous ssl handshakes
- schema changes to support starred items

* Fri Nov 20 2009 Dennis Gilmore <dennis@ausil.us> - 1.3.2-1
- update to 1.3.2

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Feb 20 2009 Dennis Gilmore <dennis@ausil.us> - 1.3.1-1
- update to 1.3.1

* Wed Feb 18 2009 Dennis Gilmore <dennis@ausil.us> - 1.3.0-1
- update to 1.3.0

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.2.6-2
- Rebuild for Python 2.6

* Mon Aug 25 2008 Dennis Gilmore <dennis@ausil.us> - 1.2.6-1
- update to 1.2.6
- make sure we have to correct version of createrepo on Fedora 8 

* Tue Aug  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.5-2
- fix conditional (line 5)
- fix license tag

* Fri Jan 25 2008 jkeating <jkeating@redhat.com> 1.2.5-1
- Put createrepo arguments in correct order

* Thu Jan 24 2008 jkeating <jkeating@redhat.com> 1.2.4-1
- Use the --skip-stat flag in createrepo calls.
- canonicalize tag arches before using them (dgilmore)
- fix return value of delete_build
- Revert to getfile urls if the task is not successful in emails
- Pass --target instead of --arch to mock.
- ignore trashcan tag in prune-signed-copies command
- add the "allowed_scms" kojid parameter
- allow filtering builds by the person who built them

* Fri Dec 14 2007 jkeating <jkeating@redhat.com> 1.2.3-1
- New upstream release with lots of updates, bugfixes, and enhancements.

* Tue Jun  5 2007 Mike Bonnet <mikeb@redhat.com> - 1.2.2-1
- only allow admins to perform non-scratch builds from srpm
- bug fixes to the cmd-line and web UIs

* Thu May 31 2007 Mike Bonnet <mikeb@redhat.com> - 1.2.1-1
- don't allow ExclusiveArch to expand the archlist (bz#239359)
- add a summary line stating whether the task succeeded or failed to the end of the "watch-task" output
- add a search box to the header of every page in the web UI
- new koji download-build command (patch provided by Dan Berrange)

* Tue May 15 2007 Mike Bonnet <mikeb@redhat.com> - 1.2.0-1
- change version numbering to a 3-token scheme
- install the koji favicon

* Mon May 14 2007 Mike Bonnet <mikeb@redhat.com> - 1.1-5
- cleanup koji-utils Requires
- fix encoding and formatting in email notifications
- expand archlist based on ExclusiveArch/BuildArchs
- allow import of rpms without srpms
- commit before linking in prepRepo to release db locks
- remove exec bit from kojid logs and uploaded files (patch by Enrico Scholz)

* Tue May  1 2007 Mike Bonnet <mikeb@redhat.com> - 1.1-4
- remove spurious Requires: from the koji-utils package

* Tue May  1 2007 Mike Bonnet <mikeb@redhat.com> - 1.1-3
- fix typo in BuildNotificationTask (patch provided by Michael Schwendt)
- add the --changelog param to the buildinfo command
- always send email notifications to the package builder and package owner
- improvements to the web UI

* Tue Apr 17 2007 Mike Bonnet <mikeb@redhat.com> - 1.1-2
- re-enable use of the --update flag to createrepo

* Mon Apr 09 2007 Jesse Keating <jkeating@redhat.com> 1.1-1
- make the output listPackages() consistent regardless of with_dups
- prevent large batches of repo deletes from holding up regens
- allow sorting the host list by arches

* Mon Apr 02 2007 Jesse Keating <jkeating@redhat.com> 1.0-1
- Release 1.0!

* Wed Mar 28 2007 Mike Bonnet <mikeb@redhat.com> - 0.9.7-4
- set SSL connection timeout to 12 hours

* Wed Mar 28 2007 Mike Bonnet <mikeb@redhat.com> - 0.9.7-3
- avoid SSL renegotiation
- improve log file handling in kojid
- bug fixes in command-line and web UI

* Sun Mar 25 2007 Mike Bonnet <mikeb@redhat.com> - 0.9.7-2
- enable http access to packages in kojid
- add Requires: pyOpenSSL
- building srpms from CVS now works with the Extras CVS structure
- fixes to the chain-build command
- bug fixes in the XML-RPC and web interfaces

* Tue Mar 20 2007 Jesse Keating <jkeating@redhat.com> - 0.9.7-1
- Package up the needed ssl files

* Tue Mar 20 2007 Jesse Keating <jkeating@redhat.com> - 0.9.6-1
- 0.9.6 release, mostly ssl auth stuff
- use named directories for config stuff
- remove -3 requires on creatrepo, don't need that specific anymore

* Tue Feb 20 2007 Jesse Keating <jkeating@redhat.com> - 0.9.5-8
- Add Authors COPYING LGPL to the docs of the main package

* Tue Feb 20 2007 Jesse Keating <jkeating@redhat.com> - 0.9.5-7
- Move web files from /var/www to /usr/share
- Use -p in install calls
- Add rpm-python to requires for koji

* Mon Feb 19 2007 Jesse Keating <jkeating@redhat.com> - 0.9.5-6
- Clean up spec for package review

* Sun Feb 04 2007 Mike McLean <mikem@redhat.com> - 0.9.5-1
- project renamed to koji
